@@ -36,7 +36,7 @@ class AbstractFuture:
 
 
 class Future(AbstractFuture):
-    def __init__(self, future, done_callback=None):
+    def __init__(self, future, done_callback=None, pre_exception=None):
         self._future = future
         self._done_cb = done_callback  # keep compatible (such as Future(future, done_callback)), deprecated later
         self._done_cb_list = []
@@ -46,7 +46,7 @@ class Future(AbstractFuture):
         self._done = False
         self._response = None
         self._results = None
-        self._exception = None
+        self._exception = pre_exception
 
         # self.__init()
 
@@ -91,14 +91,15 @@ class Future(AbstractFuture):
                     self._done = True
                     self._condition.notify_all()
 
-        self._future.add_done_callback(async_done_callback)
+        if self._future:
+            self._future.add_done_callback(async_done_callback)
 
     def result(self, **kwargs):
         self.exception()
         with self._condition:
             # future not finished. wait callback being called.
             to = kwargs.get("timeout", None)
-            if not self._future.done() or not self._response:
+            if self._future and not self._future.done() or not self._response:
                 self._response = self._future.result(timeout=to)
                 self._results = self.on_response(self._response)
 
@@ -170,7 +171,8 @@ class Future(AbstractFuture):
 
     def cancel(self):
         with self._condition:
-            self._future.cancel()
+            if self._future:
+                self._future.cancel()
             # if not self._canceled or self._done:
             #     self._future.cancel()
             #     self._canceled = True
@@ -191,15 +193,15 @@ class Future(AbstractFuture):
             self._condition.notify_all()
 
     def exception(self):
-        if not self._future.done():
-            self._future.exception()
         if self._exception:
             raise self._exception
+        if self._future and not self._future.done():
+            self._future.exception()
 
 
 class SearchFuture(Future):
-    def __init__(self, future, done_callback=None, auto_id=True):
-        super().__init__(future, done_callback)
+    def __init__(self, future, done_callback=None, auto_id=True, pre_exception=None):
+        super().__init__(future, done_callback, pre_exception)
         self._auto_id = auto_id
 
     def on_response(self, response):
