@@ -370,7 +370,6 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(None)
     def describe_collection(self, collection_name, timeout=30, **kwargs):
-        # TODO: which request
         request = Prepare.describe_collection_request(collection_name)
         rf = self._stub.DescribeCollection.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
@@ -381,7 +380,7 @@ class GrpcHandler(AbsMilvus):
             return CollectionSchema(raw=response).dict()
 
         LOGGER.error(status)
-        raise BaseException(status.error_code, status.reason)
+        raise DescribeCollectionException(status.error_code, status.reason)
         # return Status(status.error_code, status.reason), CollectionSchema(None)
 
     @error_handler([])
@@ -454,8 +453,9 @@ class GrpcHandler(AbsMilvus):
 
         raise BaseException(status.error_code, status.reason)
 
-    @error_handler([])
-    def bulk_insert(self, collection_name, entities, ids=None, partition_tag=None, params=None, timeout=None, **kwargs):
+    # https://github.com/zilliztech/milvus-distributed/issues/1339
+    def _prepare_bulk_insert_request(self, collection_name, entities, ids=None, partition_tag=None, params=None,
+                                     timeout=None, **kwargs):
         insert_param = kwargs.get('insert_param', None)
 
         # if insert_param and not isinstance(insert_param, grpc_types.InsertParam):
@@ -465,12 +465,7 @@ class GrpcHandler(AbsMilvus):
         if not isinstance(entities, list):
             raise ParamError("None entities, please provide valid entities.")
 
-        collection_request = Prepare.describe_collection_request(collection_name)
-        rf = self._stub.DescribeCollection.future(collection_request, wait_for_ready=True, timeout=timeout)
-        response = rf.result()
-        if response.status.error_code != 0:
-            raise BaseException(response.status.error_code, response.status.reason)
-        collection_schema = CollectionSchema(raw=response).dict()
+        collection_schema = self.describe_collection(collection_name, timeout=timeout, **kwargs)
 
         auto_id = collection_schema["auto_id"]
         fields_name = list()
@@ -497,25 +492,40 @@ class GrpcHandler(AbsMilvus):
             if not ids:
                 ids = None
 
-        requset = insert_param if insert_param \
+        request = insert_param if insert_param \
             else Prepare.bulk_insert_param(collection_name, entities, partition_tag, ids, params, fields_info,
                                            auto_id=auto_id)
 
-        rf = self._stub.Insert.future(requset, wait_for_ready=True, timeout=timeout)
-        if kwargs.get("_async", False) is True:
-            cb = kwargs.get("_callback", None)
-            return InsertFuture(rf, cb)
-
-        response = rf.result()
-        if response.status.error_code == 0:
-            if auto_id:
-                return list(range(response.rowID_begin, response.rowID_end))
-            return list(ids)
-
-        raise BaseException(response.status.error_code, response.status.reason)
+        return request, auto_id
 
     @error_handler([])
-    def insert(self, collection_name, entities, ids=None, partition_tag=None, params=None, timeout=None, **kwargs):
+    def bulk_insert(self, collection_name, entities, ids=None, partition_tag=None, params=None, timeout=30, **kwargs):
+        try:
+            request, auto_id = self._prepare_bulk_insert_request(collection_name, entities, ids, partition_tag, params,
+                                                                 timeout, **kwargs)
+            rf = self._stub.Insert.future(request, wait_for_ready=True, timeout=timeout)
+            if kwargs.get("_async", False) is True:
+                cb = kwargs.get("_callback", None)
+                return InsertFuture(rf, cb)
+
+            response = rf.result()
+            if response.status.error_code == 0:
+                if auto_id:
+                    return list(range(response.rowID_begin, response.rowID_end))
+                return list(ids)
+
+            raise BaseException(response.status.error_code, response.status.reason)
+        # except DescribeCollectionException as desc_error:
+        #     if kwargs.get("_async", False):
+        #         return InsertFuture(None, None, desc_error)
+        #     raise desc_error
+        except Exception as err:
+            if kwargs.get("_async", False):
+                return InsertFuture(None, None, err)
+            raise err
+
+    @error_handler([])
+    def insert(self, collection_name, entities, ids=None, partition_tag=None, params=None, timeout=30, **kwargs):
         insert_param = kwargs.get('insert_param', None)
 
         # if insert_param and not isinstance(insert_param, grpc_types.InsertParam):
@@ -575,37 +585,56 @@ class GrpcHandler(AbsMilvus):
 
         raise BaseException(response.status.error_code, response.status.reason)
 
-    @error_handler(None)
-    def search(self, collection_name, query_entities, partition_tags=None, fields=None, **kwargs):
+    def _prepare_search_request(self, collection_name, query_entities, partition_tags=None, fields=None, **kwargs):
         to = kwargs.get("timeout", None)
         rf = self._stub.HasCollection.future(Prepare.has_collection_request(collection_name), wait_for_ready=True,
                                              timeout=to)
         reply = rf.result()
         if reply.status.error_code != 0 or not reply.value:
-            raise BaseException(reply.status.error_code, "collection not exists")
+            raise CollectionNotExistException(reply.status.error_code, "collection not exists")
 
         request = Prepare.search_request(collection_name, query_entities, partition_tags, fields)
-        self._search_hook.pre_search()
-        ft = self._stub.Search.future(request, wait_for_ready=True, timeout=to)
         collection_schema = self.describe_collection(collection_name=collection_name)
         auto_id = collection_schema["auto_id"]
-        if kwargs.get("_async", False) is True:
-            func = kwargs.get("_callback", None)
-            return SearchFuture(ft, func, auto_id)
 
-        response = ft.result()
-        self._search_hook.aft_search()
+        return request, auto_id
 
-        if self._search_hook.on_response():
-            return response
+    @error_handler(None)
+    def search(self, collection_name, query_entities, partition_tags=None, fields=None, **kwargs):
+        to = kwargs.get("timeout", None)
 
-        if response.status.error_code != 0:
-            raise BaseException(response.status.error_code, response.status.reason)
+        try:
+            request, auto_id = self._prepare_search_request(collection_name, query_entities, partition_tags,
+                                                            fields=None, **kwargs)
 
-        # TODO: handler response
-        # resutls = self._search_hook.handle_response(response)
+            self._search_hook.pre_search()
 
-        return QueryResult(response, auto_id)
+            ft = self._stub.Search.future(request, wait_for_ready=True, timeout=to)
+            if kwargs.get("_async", False) is True:
+                func = kwargs.get("_callback", None)
+                return SearchFuture(ft, func, auto_id)
+
+            response = ft.result()
+            self._search_hook.aft_search()
+
+            if self._search_hook.on_response():
+                return response
+
+            if response.status.error_code != 0:
+                raise BaseException(response.status.error_code, response.status.reason)
+
+            # TODO: handler response
+            # resutls = self._search_hook.handle_response(response)
+
+            return QueryResult(response, auto_id)
+        # except (CollectionNotExistException, DescribeCollectionException) as err:
+        #     if kwargs.get("_async", False):
+        #         return SearchFuture(None, None, True, err)
+        #     raise err
+        except Exception as pre_err:
+            if kwargs.get("_async", False):
+                return SearchFuture(None, None, True, pre_err)
+            raise pre_err
 
     @error_handler(None)
     def get_query_segment_infos(self, collection_name, timeout=30, **kwargs):
