@@ -2,6 +2,7 @@ import abc
 import copy
 import struct
 import ujson
+import mmh3
 
 from .exceptions import ParamError
 
@@ -307,7 +308,7 @@ class Prepare:
 
         # generate hash keys, TODO: better hash function
         if ids is not None:
-            hash_keys = [len(str(e)) for e in ids]
+            hash_keys = [abs(mmh3.hash(str(e))) for e in ids]
             insert_request.hash_keys.extend(hash_keys)
 
         return insert_request
@@ -433,7 +434,7 @@ class Prepare:
 
         # generate hash keys, TODO: better hash function
         if ids is not None:
-            hash_keys = [len(str(e)) for e in ids]
+            hash_keys = [abs(mmh3.hash(str(e))) for e in ids]
             row_batch.hash_keys.extend(hash_keys)
 
         return row_batch
