@@ -752,7 +752,7 @@ class Milvus:
             return handler.describe_index(collection_name, field_name, timeout)
 
     @check_connect
-    def insert(self, collection_name, entities, ids=None, partition_tag=None, timeout=None, **kwargs):
+    def insert(self, collection_name, entities, ids=None, partition_tag=None, timeout=30, **kwargs):
         """
         Inserts entities in a specified collection.
 
