@@ -80,12 +80,13 @@ class DataType(IntEnum):
 
 
 class RangeType(IntEnum):
-    LT = 0   # less than
+    LT = 0  # less than
     LTE = 1  # less than or equal
-    EQ = 2   # equal
-    GT = 3   # greater than
+    EQ = 2  # equal
+    GT = 3  # greater than
     GTE = 4  # greater than or equal
-    NE = 5   # not equal
+    NE = 5  # not equal
+
 
 class IndexType(IntEnum):
     INVALID = 0
@@ -126,3 +127,54 @@ class MetricType(IntEnum):
 
     def __str__(self):
         return self._name_
+
+
+class IndexState(IntEnum):
+    IndexStateNone = 0
+    Unissued = 1
+    InProgress = 2
+    Finished = 3
+    Failed = 4
+    Deleted = 5
+
+
+class ErrorCode(IntEnum):
+    Success = 0
+    UnexpectedError = 1
+    ConnectFailed = 2
+    PermissionDenied = 3
+    CollectionNotExists = 4
+    IllegalArgument = 5
+    IllegalDimension = 7
+    IllegalIndexType = 8
+    IllegalCollectionName = 9
+    IllegalTOPK = 10
+    IllegalRowRecord = 11
+    IllegalVectorID = 12
+    IllegalSearchResult = 13
+    FileNotFound = 14
+    MetaFailed = 15
+    CacheFailed = 16
+    CannotCreateFolder = 17
+    CannotCreateFile = 18
+    CannotDeleteFolder = 19
+    CannotDeleteFile = 20
+    BuildIndexError = 21
+    IllegalNLIST = 22
+    IllegalMetricType = 23
+    OutOfMemory = 24
+    IndexNotExist = 25
+
+
+class SegmentState(IntEnum):
+    SegmentStateNone = 0
+    NotExist = 1
+    Growing = 2
+    Sealed = 3
+    Flushed = 4
+
+
+class PlaceholderType(IntEnum):
+    NoneType = 0
+    BinaryVector = 100
+    FloatVector = 101
